@@ -12,11 +12,11 @@
 
 #define GLYR_VERSION_MAJOR "1"
 #define GLYR_VERSION_MINOR "0"
-#define GLYR_VERSION_MICRO "1"
+#define GLYR_VERSION_MICRO "8"
 
 #define GLYR_VERSION_MAJOR_INT 1
 #define GLYR_VERSION_MINOR_INT 0
-#define GLYR_VERSION_MICRO_INT 1
+#define GLYR_VERSION_MICRO_INT 8
 
 /**
  * GLYR_CHECK_VERSION:
@@ -36,8 +36,8 @@
 */
 #define GLYR_CHECK_VERSION(X,Y,Z) (X <= GLYR_VERSION_MAJOR_INT || Y <= GLYR_VERSION_MINOR_INT || Z <= GLYR_VERSION_MICRO_INT)
 
-#define GLYR_VERSION_NAME  "Bloody Boar"
-#define GLYR_DEBUG         TRUE
+#define GLYR_VERSION_NAME  "Raving Raven"
+#define GLYR_DEBUG         FALSE
 
 /* Message output */
 #define GLYR_OUTPUT stderr
